@@ -33,6 +33,7 @@ class UniversalWrapper:
             self.uw_settings["flag_divider"] = flag_divider
             self.uw_settings["input_modifiers"] = input_modifiers
             self.uw_settings["output_modifiers"] = output_modifiers
+            self.uw_settings["debug"] = False
         else:
             self.uw_settings = uw_settings
             self.uw_settings["cmd"] = cmd
@@ -41,6 +42,10 @@ class UniversalWrapper:
     def run_cmd(self, command):
         command = self.input_modifier(command)
         command = self.remove_flags(command)
+        if self.uw_settings["debug"]:
+            print("Executing")
+            print(command)
+            print(">>")
         output = subprocess.check_output(command, shell=True)
         return self.output_modifier(output)
 
@@ -92,8 +97,11 @@ class UniversalWrapper:
         return command
 
     def remove_flags(self, command):
+        input_modifiers = self.uw_settings["input_modifiers"].keys()
         for flag in self.flags_to_remove:
-            command = command.replace(flag.strip(), "")
+            for input_modifier in input_modifiers:
+                if flag in input_modifier:
+                    command = command.replace(input_modifier, "")
         self.flags_to_remove = []
         return command
 
@@ -117,4 +125,5 @@ class UniversalWrapper:
         )
         return subclass
 
-sys.modules[__name__] = UniversalWrapper("")
\ No newline at end of file
+def __getattr__(attr):
+    return UniversalWrapper(attr)
